function [Az Alt] = RaDec2AzAlt(RA,Dec,UTC,Lat,Lon)

% Written by Liviu Ivanescu <ivanescu@sca.uqam.ca> 2012-08-17
% Based on RaDec2AzEL by Frank Breitling <fbreitling@aip.de> 2009-10-20
% from the program SolarAzEl by Darin C. Koblick 02/17/2009
%
% Function Description:
% RADecAzAlt will ingest a sky position in equatorial coordinates (J2000), 
% a Universal Time, and specific location on earth. It will then
% output the azimuth and elevation angles in the local horizon system.
%
% Input Description:
% Ra    Right ascension (J2000) of sky position in degrees (0:360)
% Dec   Declination angle (J2000) of sky position in degrees (-90:90)
% UTC   Coordinated Universal Time (Matlab numerical time format)
% Lat   Latitude of location in degrees -90:90 -> S(-) N(+)
% Lon   Longitude of location in degrees -180:180 W(-) E(+)
%
% Output Description:
% Az    Azimuth angle of position in degrees (0:360)
% Alt   Elevation angle of position in degrees (-90:90)
%
% Source References:
% http://www.mathworks.com/matlabcentral/fileexchange/23051-solar-azimuth-and-elevation-estimation


% Code Sequence:

% Compute JD
jd = juliandate(datevec(UTC));
d = jd-2451543.5;

% Keplerian Elements for the Sun (geocentric)
w = 282.9404+4.70935e-5*d;            % longitude of perihelion degrees
M = mod(356.0470+0.9856002585*d,360); % mean anomaly degrees
L = w + M;                            % Sun's mean longitude degrees

% Following the RA DEC to Az Alt conversion sequence explained here:
% http://www.stargazing.net/kepler/altaz.html

% Find the J2000 value
J2000 = jd - 2451545.0;
hourvec = datevec(UTC);
UTH = hourvec(:,4) + hourvec(:,5)/60 + hourvec(:,6)/3600;

% Calculate local siderial time
GMST0=mod(L+180,360)/15;
SIDTIME = GMST0 + UTH + Lon/15;

% Replace RA with hour angle HA
HA = (SIDTIME'*15 - RA);

% Convert to rectangular coordinate system
x = cos(HA*pi/180).*cos(Dec*pi/180);
y = sin(HA*pi/180).*cos(Dec*pi/180);
z = sin(Dec*pi/180);

% Rotate this along an axis going east-west.
xhor = x.*cos((90-Lat)*pi/180)-z.*sin((90-Lat)*pi/180);
yhor = y;
zhor = x.*sin((90-Lat)*pi/180)+z.*cos((90-Lat)*pi/180);

% Find the h and AZ 
Az = atan2(yhor,xhor)*180/pi + 180;
Alt = asin(zhor)*180/pi;
